/*
 * Copyright (c) 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This file was generated.
 *  with google-apis-code-generator 1.1.1 (build: 2012-03-12 19:56:39 UTC)
 *  on 2012-03-12 at 20:55:58 UTC 
 */

package com.google.api.services.urlshortener;


import com.google.api.client.googleapis.services.GoogleClient;
import com.google.api.client.http.GenericUrl;
import com.google.api.client.http.HttpMethod;
import com.google.api.client.http.HttpRequest;
import com.google.api.client.http.HttpRequestInitializer;
import com.google.api.client.http.HttpResponse;
import com.google.api.client.http.HttpTransport;
import com.google.api.client.http.json.JsonHttpRequest;
import com.google.api.client.http.json.JsonHttpRequestInitializer;
import com.google.api.client.json.JsonFactory;
import com.google.api.client.util.Key;
import com.google.common.base.Preconditions;

import java.io.IOException;


/**
 * Service definition for Urlshortener (v1).
 *
 * <p>
 * Lets you create, inspect, and manage goo.gl short URLs
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="http://code.google.com/apis/urlshortener/v1/getting_started.html" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link JsonHttpRequestInitializer} to initialize global parameters via its
 * {@link Builder}. Sample usage:
 * </p>
 *
 * <pre>
  public class UrlshortenerRequestInitializer implements JsonHttpRequestInitializer {
      public void initialize(JsonHttpRequest request) {
        UrlshortenerRequest urlshortenerRequest = (UrlshortenerRequest)request;
        urlshortenerRequest.setPrettyPrint(true);
        urlshortenerRequest.setKey(ClientCredentials.KEY);
    }
  }
 * </pre>
 *
 * @since 1.3.0
 * @author Google, Inc.
 */
public class Urlshortener extends GoogleClient {

  /**
   * The default encoded base path of the service. This is determined when the library is generated
   * and normally should not be changed.
   */
  public static final String DEFAULT_BASE_PATH = "/urlshortener/v1/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   */
  public static final String DEFAULT_BASE_URL = "https://www.googleapis.com" + DEFAULT_BASE_PATH;

  /**
   * Construct a Urlshortener instance to connect to the Urlshortener service.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport The transport to use for requests
   * @param jsonFactory A factory for creating JSON parsers and serializers
   */
  public Urlshortener(HttpTransport transport, JsonFactory jsonFactory) {
    super(transport, jsonFactory, DEFAULT_BASE_URL);
  }

  /**
   * Construct a Urlshortener instance to connect to the Urlshortener service.
   *
   * @param transport The transport to use for requests
   * @param jsonHttpRequestInitializer The initializer to use when creating an JSON HTTP request
   * @param httpRequestInitializer The initializer to use when creating an {@link HttpRequest}
   * @param jsonFactory A factory for creating JSON parsers and serializers
   * @param baseUrl The base url of the service on the server
   * @param applicationName The application name to be sent in the User-Agent header of requests
   */
  Urlshortener(
      HttpTransport transport,
      JsonHttpRequestInitializer jsonHttpRequestInitializer,
      HttpRequestInitializer httpRequestInitializer,
      JsonFactory jsonFactory,
      String baseUrl,
      String applicationName) {
      super(transport,
          jsonHttpRequestInitializer,
          httpRequestInitializer,
          jsonFactory,
          baseUrl,
          applicationName);
  }

  /**
   * Returns an instance of a new builder.
   *
   * @param transport The transport to use for requests
   * @param jsonFactory A factory for creating JSON parsers and serializers
   */
   public static Builder builder(HttpTransport transport, JsonFactory jsonFactory) {
     return new Builder(transport, jsonFactory);
   }

  /**
   * An accessor for creating requests from the Url collection.
   *
   * The typical use is:<pre>
   *   {@code Urlshortener urlshortener = new Urlshortener(...);}
   *   {@code Urlshortener.Url.List request = urlshortener.url().list(parameters ...)}</pre>
   *
   * @return the resource collection
   */
  public Url url() {
    return new Url();
  }

  /**
   * The "url" collection of methods.
   */
  public class Url {

    /**
     * Creates a new short URL.
     *
     * Create a request for the method "url.insert".
     *
     * This request holds the parameters needed by the the urlshortener server.  After setting any
     * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param content the {@link Url}
     * @return the request
     * @throws IOException if the initialization of the request fails
     */
    public Insert insert(com.google.api.services.urlshortener.model.Url content) throws IOException {
      Insert result = new Insert(content);
      initialize(result);
      return result;
    }


    public class Insert extends UrlshortenerRequest {

      private static final String REST_PATH = "url";

      /**
       * Internal constructor.  Use the convenience method instead.
       */
      private Insert(com.google.api.services.urlshortener.model.Url content) {
        super(Urlshortener.this, HttpMethod.POST, REST_PATH, content);
        Preconditions.checkNotNull(content);
      }



      /**
       * Sends the "insert" request to the Urlshortener server.
       *
       * @return the {@link com.google.api.services.urlshortener.model.Url} response
       * @throws IOException if the request fails
       */
      public com.google.api.services.urlshortener.model.Url execute() throws IOException {
        HttpResponse response = executeUnparsed();
        com.google.api.services.urlshortener.model.Url result = response.parseAs(
            com.google.api.services.urlshortener.model.Url.class);
        result.setResponseHeaders(response.getHeaders());
        return result;
      }



    }
    /**
     * Retrieves a list of URLs shortened by a user.
     *
     * Create a request for the method "url.list".
     *
     * This request holds the parameters needed by the the urlshortener server.  After setting any
     * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     * @throws IOException if the initialization of the request fails
     */
    public List list() throws IOException {
      List result = new List();
      initialize(result);
      return result;
    }


    public class List extends UrlshortenerRequest {

      private static final String REST_PATH = "url/history";

      /**
       * Internal constructor.  Use the convenience method instead.
       */
      private List() {
        super(Urlshortener.this, HttpMethod.GET, REST_PATH, null);
      }



      /**
       * Sends the "list" request to the Urlshortener server.
       *
       * @return the {@link com.google.api.services.urlshortener.model.UrlHistory} response
       * @throws IOException if the request fails
       */
      public com.google.api.services.urlshortener.model.UrlHistory execute() throws IOException {
        HttpResponse response = executeUnparsed();
        com.google.api.services.urlshortener.model.UrlHistory result = response.parseAs(
            com.google.api.services.urlshortener.model.UrlHistory.class);
        result.setResponseHeaders(response.getHeaders());
        return result;
      }


      /** Token for requesting successive pages of results. */
      @Key("start-token")
      private String startToken;

      /**  Token for requesting successive pages of results.
       */
      public String getStartToken() {
        return startToken;
      }

      /** Token for requesting successive pages of results. */
      public List setStartToken(String startToken) {
        this.startToken = startToken;
        return this;
      }

      /** Additional information to return. */
      @Key
      private String projection;

      /**  Additional information to return.
       */
      public String getProjection() {
        return projection;
      }

      /** Additional information to return. */
      public List setProjection(String projection) {
        this.projection = projection;
        return this;
      }


    }
    /**
     * Expands a short URL or gets creation time and analytics.
     *
     * Create a request for the method "url.get".
     *
     * This request holds the parameters needed by the the urlshortener server.  After setting any
     * optional parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param shortUrl The short URL, including the protocol.
     * @return the request
     * @throws IOException if the initialization of the request fails
     */
    public Get get(String shortUrl) throws IOException {
      Get result = new Get(shortUrl);
      initialize(result);
      return result;
    }


    public class Get extends UrlshortenerRequest {

      private static final String REST_PATH = "url";

      /**
       * Internal constructor.  Use the convenience method instead.
       */
      private Get(String shortUrl) {
        super(Urlshortener.this, HttpMethod.GET, REST_PATH, null);
        this.shortUrl = Preconditions.checkNotNull(shortUrl, "Required parameter shortUrl must be specified.");
      }



      /**
       * Sends the "get" request to the Urlshortener server.
       *
       * @return the {@link com.google.api.services.urlshortener.model.Url} response
       * @throws IOException if the request fails
       */
      public com.google.api.services.urlshortener.model.Url execute() throws IOException {
        HttpResponse response = executeUnparsed();
        com.google.api.services.urlshortener.model.Url result = response.parseAs(
            com.google.api.services.urlshortener.model.Url.class);
        result.setResponseHeaders(response.getHeaders());
        return result;
      }


      /** The short URL, including the protocol. */
      @Key
      private String shortUrl;

      /**  The short URL, including the protocol.
       */
      public String getShortUrl() {
        return shortUrl;
      }

      /** The short URL, including the protocol. */
      public Get setShortUrl(String shortUrl) {
        this.shortUrl = shortUrl;
        return this;
      }

      /** Additional information to return. */
      @Key
      private String projection;

      /**  Additional information to return.
       */
      public String getProjection() {
        return projection;
      }

      /** Additional information to return. */
      public Get setProjection(String projection) {
        this.projection = projection;
        return this;
      }


    }

  }



  /**
   * Builder for {@link Urlshortener}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends GoogleClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport The transport to use for requests
     * @param jsonFactory A factory for creating JSON parsers and serializers
     */
    Builder(HttpTransport transport, JsonFactory jsonFactory) {
      super(transport, jsonFactory, new GenericUrl(DEFAULT_BASE_URL));
    }

    /** Builds a new instance of {@link Urlshortener}. */
    @Override
    public Urlshortener build() {
      return new Urlshortener(
          getTransport(),
          getJsonHttpRequestInitializer(),
          getHttpRequestInitializer(),
          getJsonFactory(),
          getBaseUrl().build(),
          getApplicationName());
    }

    @Override
    public Builder setBaseUrl(GenericUrl baseUrl) {
      super.setBaseUrl(baseUrl);
      return this;
    }

    @Override
    public Builder setJsonHttpRequestInitializer(
        JsonHttpRequestInitializer jsonHttpRequestInitializer) {
      super.setJsonHttpRequestInitializer(jsonHttpRequestInitializer);
      return this;
    }

    @Override
    public Builder setHttpRequestInitializer(HttpRequestInitializer httpRequestInitializer) {
      super.setHttpRequestInitializer(httpRequestInitializer);
      return this;
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      super.setApplicationName(applicationName);
      return this;
    }
  }
}
