/*
 * Copyright (c) 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.urlshortener.model;


import com.google.api.client.http.HttpHeaders;
import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.api.client.util.Key;


/**
 * Model definition for AnalyticsSnapshot.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the URL Shortener API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * @author Google, Inc.
 */
public final class AnalyticsSnapshot extends GenericJson {


  /**
   * Number of clicks on this short URL.
   * The value may be {@code null}.
   */
  @Key @JsonString
  private Long shortUrlClicks;

  /**
   * Top countries (expressed as country codes), e.g. "US" or "DE"; sorted by (descending) click
   * counts. Only present if this data is available.
   * The value may be {@code null}.
   */
  @Key
  private java.util.List<StringCount> countries;

  /**
   * Top platforms or OSes, e.g. "Windows"; sorted by (descending) click counts. Only present if
   * this data is available.
   * The value may be {@code null}.
   */
  @Key
  private java.util.List<StringCount> platforms;

  /**
   * Top browsers, e.g. "Chrome"; sorted by (descending) click counts. Only present if this data is
   * available.
   * The value may be {@code null}.
   */
  @Key
  private java.util.List<StringCount> browsers;

  /**
   * Top referring hosts, e.g. "www.google.com"; sorted by (descending) click counts. Only present
   * if this data is available.
   * The value may be {@code null}.
   */
  @Key
  private java.util.List<StringCount> referrers;

  /**
   * Number of clicks on all goo.gl short URLs pointing to this long URL.
   * The value may be {@code null}.
   */
  @Key @JsonString
  private Long longUrlClicks;

  /**
   * Number of clicks on this short URL.
   * The value returned may be {@code null}.
   */
  public Long getShortUrlClicks() {
    return shortUrlClicks;
  }

  /**
   * Number of clicks on this short URL.
   * The value set may be {@code null}.
   */
  public AnalyticsSnapshot setShortUrlClicks(Long shortUrlClicks) {
    this.shortUrlClicks = shortUrlClicks;
    return this;
  }

  /**
   * Top countries (expressed as country codes), e.g. "US" or "DE"; sorted by (descending) click
   * counts. Only present if this data is available.
   * The value returned may be {@code null}.
   */
  public java.util.List<StringCount> getCountries() {
    return countries;
  }

  /**
   * Top countries (expressed as country codes), e.g. "US" or "DE"; sorted by (descending) click
   * counts. Only present if this data is available.
   * The value set may be {@code null}.
   */
  public AnalyticsSnapshot setCountries(java.util.List<StringCount> countries) {
    this.countries = countries;
    return this;
  }

  /**
   * Top platforms or OSes, e.g. "Windows"; sorted by (descending) click counts. Only present if
   * this data is available.
   * The value returned may be {@code null}.
   */
  public java.util.List<StringCount> getPlatforms() {
    return platforms;
  }

  /**
   * Top platforms or OSes, e.g. "Windows"; sorted by (descending) click counts. Only present if
   * this data is available.
   * The value set may be {@code null}.
   */
  public AnalyticsSnapshot setPlatforms(java.util.List<StringCount> platforms) {
    this.platforms = platforms;
    return this;
  }

  /**
   * Top browsers, e.g. "Chrome"; sorted by (descending) click counts. Only present if this data is
   * available.
   * The value returned may be {@code null}.
   */
  public java.util.List<StringCount> getBrowsers() {
    return browsers;
  }

  /**
   * Top browsers, e.g. "Chrome"; sorted by (descending) click counts. Only present if this data is
   * available.
   * The value set may be {@code null}.
   */
  public AnalyticsSnapshot setBrowsers(java.util.List<StringCount> browsers) {
    this.browsers = browsers;
    return this;
  }

  /**
   * Top referring hosts, e.g. "www.google.com"; sorted by (descending) click counts. Only present
   * if this data is available.
   * The value returned may be {@code null}.
   */
  public java.util.List<StringCount> getReferrers() {
    return referrers;
  }

  /**
   * Top referring hosts, e.g. "www.google.com"; sorted by (descending) click counts. Only present
   * if this data is available.
   * The value set may be {@code null}.
   */
  public AnalyticsSnapshot setReferrers(java.util.List<StringCount> referrers) {
    this.referrers = referrers;
    return this;
  }

  /**
   * Number of clicks on all goo.gl short URLs pointing to this long URL.
   * The value returned may be {@code null}.
   */
  public Long getLongUrlClicks() {
    return longUrlClicks;
  }

  /**
   * Number of clicks on all goo.gl short URLs pointing to this long URL.
   * The value set may be {@code null}.
   */
  public AnalyticsSnapshot setLongUrlClicks(Long longUrlClicks) {
    this.longUrlClicks = longUrlClicks;
    return this;
  }


  private HttpHeaders responseHeaders;

  /**
   * Sets the HTTP headers returned with the server response, or <code>null</code>.
   *
   * This member should only be non-null if this object was the top level element of a response. For
   * example, a request that returns a single {@link AnalyticsSnapshot} would include the response
   * headers, while a request which returns an array of {@link AnalyticsSnapshot}, would have a non-
   * null response header in the enclosing object only.
   */
  public void setResponseHeaders(HttpHeaders responseHeaders) {
    this.responseHeaders = responseHeaders;
  }

  /**
   * Returns the HTTP headers that were returned with the server response, or
   * <code>null</code>.
   */
  public HttpHeaders getResponseHeaders() {
    return responseHeaders;
  }






}
