/*
 * Copyright (c) 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.urlshortener.model;


import com.google.api.client.http.HttpHeaders;
import com.google.api.client.json.GenericJson;
import com.google.api.client.util.Key;


/**
 * Model definition for AnalyticsSummary.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the URL Shortener API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * @author Google, Inc.
 */
public final class AnalyticsSummary extends GenericJson {


  /**
   * Click analytics over the last week.
   * The value may be {@code null}.
   */
  @Key
  private AnalyticsSnapshot week;

  /**
   * Click analytics over all time.
   * The value may be {@code null}.
   */
  @Key
  private AnalyticsSnapshot allTime;

  /**
   * Click analytics over the last two hours.
   * The value may be {@code null}.
   */
  @Key
  private AnalyticsSnapshot twoHours;

  /**
   * Click analytics over the last day.
   * The value may be {@code null}.
   */
  @Key
  private AnalyticsSnapshot day;

  /**
   * Click analytics over the last month.
   * The value may be {@code null}.
   */
  @Key
  private AnalyticsSnapshot month;

  /**
   * Click analytics over the last week.
   * The value returned may be {@code null}.
   */
  public AnalyticsSnapshot getWeek() {
    return week;
  }

  /**
   * Click analytics over the last week.
   * The value set may be {@code null}.
   */
  public AnalyticsSummary setWeek(AnalyticsSnapshot week) {
    this.week = week;
    return this;
  }

  /**
   * Click analytics over all time.
   * The value returned may be {@code null}.
   */
  public AnalyticsSnapshot getAllTime() {
    return allTime;
  }

  /**
   * Click analytics over all time.
   * The value set may be {@code null}.
   */
  public AnalyticsSummary setAllTime(AnalyticsSnapshot allTime) {
    this.allTime = allTime;
    return this;
  }

  /**
   * Click analytics over the last two hours.
   * The value returned may be {@code null}.
   */
  public AnalyticsSnapshot getTwoHours() {
    return twoHours;
  }

  /**
   * Click analytics over the last two hours.
   * The value set may be {@code null}.
   */
  public AnalyticsSummary setTwoHours(AnalyticsSnapshot twoHours) {
    this.twoHours = twoHours;
    return this;
  }

  /**
   * Click analytics over the last day.
   * The value returned may be {@code null}.
   */
  public AnalyticsSnapshot getDay() {
    return day;
  }

  /**
   * Click analytics over the last day.
   * The value set may be {@code null}.
   */
  public AnalyticsSummary setDay(AnalyticsSnapshot day) {
    this.day = day;
    return this;
  }

  /**
   * Click analytics over the last month.
   * The value returned may be {@code null}.
   */
  public AnalyticsSnapshot getMonth() {
    return month;
  }

  /**
   * Click analytics over the last month.
   * The value set may be {@code null}.
   */
  public AnalyticsSummary setMonth(AnalyticsSnapshot month) {
    this.month = month;
    return this;
  }


  private HttpHeaders responseHeaders;

  /**
   * Sets the HTTP headers returned with the server response, or <code>null</code>.
   *
   * This member should only be non-null if this object was the top level element of a response. For
   * example, a request that returns a single {@link AnalyticsSummary} would include the response
   * headers, while a request which returns an array of {@link AnalyticsSummary}, would have a non-
   * null response header in the enclosing object only.
   */
  public void setResponseHeaders(HttpHeaders responseHeaders) {
    this.responseHeaders = responseHeaders;
  }

  /**
   * Returns the HTTP headers that were returned with the server response, or
   * <code>null</code>.
   */
  public HttpHeaders getResponseHeaders() {
    return responseHeaders;
  }
}
