/*
 * Copyright (c) 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.urlshortener.model;


import com.google.api.client.http.HttpHeaders;
import com.google.api.client.json.GenericJson;
import com.google.api.client.util.Key;


/**
 * Model definition for UrlHistory.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the URL Shortener API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * @author Google, Inc.
 */
public final class UrlHistory extends GenericJson {


  /**
   * A token to provide to get the next page of results.
   * The value may be {@code null}.
   */
  @Key
  private String nextPageToken;

  /**
   * A list of URL resources.
   * The value may be {@code null}.
   */
  @Key
  private java.util.List<Url> items;

  /**
   * The fixed string "urlshortener#urlHistory".
   * The value may be {@code null}.
   */
  @Key
  private String kind;

  /**
   * Number of items returned with each full "page" of results. Note that the last page could have
   * fewer items than the "itemsPerPage" value.
   * The value may be {@code null}.
   */
  @Key
  private Integer itemsPerPage;

  /**
   * Total number of short URLs associated with this user (may be approximate).
   * The value may be {@code null}.
   */
  @Key
  private Integer totalItems;

  /**
   * A token to provide to get the next page of results.
   * The value returned may be {@code null}.
   */
  public String getNextPageToken() {
    return nextPageToken;
  }

  /**
   * A token to provide to get the next page of results.
   * The value set may be {@code null}.
   */
  public UrlHistory setNextPageToken(String nextPageToken) {
    this.nextPageToken = nextPageToken;
    return this;
  }

  /**
   * A list of URL resources.
   * The value returned may be {@code null}.
   */
  public java.util.List<Url> getItems() {
    return items;
  }

  /**
   * A list of URL resources.
   * The value set may be {@code null}.
   */
  public UrlHistory setItems(java.util.List<Url> items) {
    this.items = items;
    return this;
  }

  /**
   * The fixed string "urlshortener#urlHistory".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The fixed string "urlshortener#urlHistory".
   * The value set may be {@code null}.
   */
  public UrlHistory setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Number of items returned with each full "page" of results. Note that the last page could have
   * fewer items than the "itemsPerPage" value.
   * The value returned may be {@code null}.
   */
  public Integer getItemsPerPage() {
    return itemsPerPage;
  }

  /**
   * Number of items returned with each full "page" of results. Note that the last page could have
   * fewer items than the "itemsPerPage" value.
   * The value set may be {@code null}.
   */
  public UrlHistory setItemsPerPage(Integer itemsPerPage) {
    this.itemsPerPage = itemsPerPage;
    return this;
  }

  /**
   * Total number of short URLs associated with this user (may be approximate).
   * The value returned may be {@code null}.
   */
  public Integer getTotalItems() {
    return totalItems;
  }

  /**
   * Total number of short URLs associated with this user (may be approximate).
   * The value set may be {@code null}.
   */
  public UrlHistory setTotalItems(Integer totalItems) {
    this.totalItems = totalItems;
    return this;
  }


  private HttpHeaders responseHeaders;

  /**
   * Sets the HTTP headers returned with the server response, or <code>null</code>.
   *
   * This member should only be non-null if this object was the top level element of a response. For
   * example, a request that returns a single {@link UrlHistory} would include the response headers,
   * while a request which returns an array of {@link UrlHistory}, would have a non-null response
   * header in the enclosing object only.
   */
  public void setResponseHeaders(HttpHeaders responseHeaders) {
    this.responseHeaders = responseHeaders;
  }

  /**
   * Returns the HTTP headers that were returned with the server response, or
   * <code>null</code>.
   */
  public HttpHeaders getResponseHeaders() {
    return responseHeaders;
  }





}
